IntoObserverSystem

Trait IntoObserverSystem 

pub trait IntoObserverSystem<E, M, Out = ()>: Send + 'static
where E: EventPattern,
{ type System: ObserverSystem<E, Out>; // Required method fn into_system(this: Self) -> Self::System; }
Implemented for systems that convert into ObserverSystem.

Usage notes

This trait should only be used as a bound for trait implementations or as an argument to a function. If an observer system needs to be returned from a function or stored somewhere, use ObserverSystem instead of this trait.

Required Associated Types

type System: ObserverSystem<E, Out>

The type of System that this instance converts into.

Required Methods

fn into_system(this: Self) -> Self::System

Turns this value into its corresponding System.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E, M, Out, S> IntoObserverSystem<E, M, Out> for S
where E: EventPattern + 'static, S: IntoSystem<On<'static, 'static, E>, Out, M> + Send + 'static, <S as IntoSystem<On<'static, 'static, E>, Out, M>>::System: ObserverSystem<E, Out>,

Source

type System = <S as IntoSystem<On<'static, 'static, E>, Out, M>>::System